#!/usr/bin/env bash

if [[ $# -ne 1 ]]; then
    GPUID=0
else
    GPUID=$1
fi

echo "RUN on GPU $GPUID"

# data
PROJECT_ROOT=$(dirname "$(readlink -f "$0")")
echo $PROJECT_ROOT

# parameters
SEED=1
EPOCH=76

BETA=4
DISTANCE='l_inf'
MODEL_TYPE='WideResnet'
DEPTH=28
WIDEN_FACTOR=1

# output
now=$(date +'%m_%d_%Y')
OUTPUT=$PROJECT_ROOT/outputs/${now}/CIFAR10_${MODEL_TYPE}/SEED_${SEED}_EPOCH_${EPOCH}_BETA_${BETA}_${DISTANCE}/${MODEL_TYPE}_${DEPTH}_${WIDEN_FACTOR}

LOGFILE=${OUTPUT}/log.out


echo $OUTPUT
[ -e $OUTPUT/script  ] || mkdir -p $OUTPUT/script


cp -f $(readlink -f "$0") $OUTPUT/script
rsync -ruzC --exclude-from=$PROJECT_ROOT/.gitignore --exclude 'data' --exclude 'outputs' --exclude 'backup' $PROJECT_ROOT/ $OUTPUT/src

CUDA_DEVICE_ORDER=PCI_BUS_ID CUDA_VISIBLE_DEVICES=$GPUID \
python3 -u resnet_cifar.py \
    --model_type ${MODEL_TYPE} \
    --depth ${DEPTH} \
    --widen_factor ${WIDEN_FACTOR} \
    --total_epoch ${EPOCH} \
    --adv_train \
    --seed ${SEED} \
    --beta ${BETA} \
    --distance ${DISTANCE} \
    --model_dir ${OUTPUT} --TRADES | tee ${LOGFILE}
